==> dash-bootstrap-components-1.7.0.tgz: package/src/components/table/Table.js <==
import React from 'react';
import PropTypes from 'prop-types';
import {omit} from 'ramda';
import RBTable from 'react-bootstrap/Table';

/**
 * A component for applying Bootstrap styles to HTML tables. Use this as a
 * drop-in replacement for `html.Table`, or generate a table from a Pandas
 * DataFrame using `dbc.Table.from_dataframe`.
 */
const Table = props => {
  const {
    children,
    loading_state,
    className,
    class_name,
    color,
    dark,
    ...otherProps
  } = props;
  return (
    <RBTable
      className={class_name || className}
      variant={color || (dark ? 'dark' : undefined)}
      {...omit(['setProps'], otherProps)}
      data-dash-is-loading={
        (loading_state && loading_state.is_loading) || undefined
      }
    >
      {children}
    </RBTable>
  );
};

Table.propTypes = {
  /**
   * The ID of this component, used to identify dash components
   * in callbacks. The ID needs to be unique across all of the
   * components in an app.
   */
  id: PropTypes.string,

  /**
   * The children of this component
   */
  children: PropTypes.node,

  /**
   * Defines CSS styles which will override styles previously set.
   */
  style: PropTypes.object,

  /**
   * Often used with CSS to style elements with common properties.
   */
  class_name: PropTypes.string,

  /**
   * **DEPRECATED** Use `class_name` instead.
   *
   * Often used with CSS to style elements with common properties.
   */
  className: PropTypes.string,

  /**
   * A unique identifier for the component, used to improve
   * performance by React.js while rendering components
   * See https://reactjs.org/docs/lists-and-keys.html for more info
   */
  key: PropTypes.string,

  /**
   * Specify table size, options: 'sm', 'md', 'lg'
   */
  size: PropTypes.string,

  /**
   * Apply the `table-bordered` class which adds borders on all sides of the
   * table and cells.
   */
  bordered: PropTypes.bool,

  /**
   * Apply the `table-borderless` class which removes all borders from the
   * table and cells.
   */
  borderless: PropTypes.bool,

  /**
   * Apply the `table-striped` class which applies 'zebra striping' to rows in
   * the table body.
   */
  striped: PropTypes.bool,

  /**
   * Table color, options: primary, secondary, success, info, warning, danger,
   * dark, light. Default: secondary.
   */
  color: PropTypes.string,

  /**
   * **DEPRECATED** - Use color="dark" instead.
   *
   * Apply the `table-dark` class for dark cell backgrounds and light text.
   */
  dark: PropTypes.bool,

  /**
   * Apply the `table-hover` class which enables a hover state on table rows
   * within the table body.
   */
  hover: PropTypes.bool,

  /**
   * Set to True or one of the breakpoints 'sm', 'md', 'lg', 'xl' to make table
   * scroll horizontally at lower breakpoints.
   */
  responsive: PropTypes.oneOfType([PropTypes.bool, PropTypes.string]),

  /**
   * Object that holds the loading state object coming from dash-renderer
   */
  loading_state: PropTypes.shape({
    /**
     * Determines if the component is loading or not
     */
    is_loading: PropTypes.bool,
    /**
     * Holds which property is loading
     */
    prop_name: PropTypes.string,
    /**
     * Holds the name of the component that is loading
     */
    component_name: PropTypes.string
  })
};

export default Table;

==> dash-bootstrap-components-2.0.0.tgz: package/src/components/table/Table.js <==
import React from 'react';

import PropTypes from 'prop-types';
import {omit} from 'ramda';
import RBTable from 'react-bootstrap/Table';

import {getLoadingState} from '../../private/util';

/**
 * A component for applying Bootstrap styles to HTML tables. Use this as a drop-in
 * replacement for `html.Table`, or generate a table from a Pandas DataFrame using
 * `dbc.Table.from_dataframe`.
 */
function Table(props) {
  const {children, class_name, color, className, ...otherProps} = props;
  return (
    <RBTable
      className={class_name || className}
      variant={color}
      {...omit(['setProps'], otherProps)}
      data-dash-is-loading={getLoadingState() || undefined}
    >
      {children}
    </RBTable>
  );
}

Table.propTypes = {
  /**
   * The children of this Table
   */
  children: PropTypes.node,

  /**
   * The ID of the Table
   */
  id: PropTypes.string,

  /**
   * Additional inline CSS styles to apply to the Table.
   */
  style: PropTypes.object,

  /**
   * Additional CSS classes to apply to the Table.
   */
  class_name: PropTypes.string,

  /**
   * Specify table size, options: 'sm', 'md', 'lg'
   */
  size: PropTypes.string,

  /**
   * Apply the `table-bordered` class which adds borders on all sides of the
   * table and cells.
   */
  bordered: PropTypes.bool,

  /**
   * Apply the `table-borderless` class which removes all borders from the
   * table and cells.
   */
  borderless: PropTypes.bool,

  /**
   * Apply the `table-striped` class which applies 'zebra striping' to rows in
   * the table body.
   */
  striped: PropTypes.bool,

  /**
   * Table color, options: primary, secondary, success, info, warning, danger,
   * dark, light. Default: secondary.
   */
  color: PropTypes.string,

  /**
   * Apply the `table-hover` class which enables a hover state on table rows
   * within the table body.
   */
  hover: PropTypes.bool,

  /**
   * Set to True or one of the breakpoints 'sm', 'md', 'lg', 'xl' to make table
   * scroll horizontally at lower breakpoints.
   */
  responsive: PropTypes.oneOfType([PropTypes.bool, PropTypes.string]),

  /**
   * A unique identifier for the component, used to improve performance by React.js
   * while rendering components
   *
   * See https://react.dev/learn/rendering-lists#why-does-react-need-keys for more info
   */
  key: PropTypes.string,

  /**
   * **DEPRECATED** Use `class_name` instead.
   *
   * Additional CSS classes to apply to the Table.
   */
  className: PropTypes.string,

  /**
   * Dash-assigned callback that gets fired when the value changes.
   */
  setProps: PropTypes.func
};

export default Table;
